Exception: Hooksmith::UnknownEventError
- Defined in:
- lib/hooksmith/errors.rb
Overview
Raised when the event name is not recognized or invalid.
This error can be raised when strict event validation is enabled and an unknown event type is received.
Instance Attribute Summary
Attributes inherited from Error
Instance Method Summary collapse
-
#initialize(provider, event) ⇒ UnknownEventError
constructor
Initializes a new UnknownEventError.
Constructor Details
#initialize(provider, event) ⇒ UnknownEventError
Initializes a new UnknownEventError.
165 166 167 168 169 170 171 |
# File 'lib/hooksmith/errors.rb', line 165 def initialize(provider, event) super( "Unknown event '#{event}' for provider '#{provider}'", provider:, event: ) end |